@@ -58,6 +58,7 @@ static layouts layout_names[] = {
     {"it",		"Italiano"},
     {"pl",		"Polski"},
     {"fise",		"Suomi, Svenska"},
+    {"ch",		"Suisse, Schweiz"},
     {"ru",		"Русский"},
     {"sk",		"Slovenčina"},
     {"sk_qwerty",	"Slovenčina - QWERTY"},
@@ -66,6 +67,7 @@ static layouts layout_names[] = {
     {"gr",		"Ελληνικά"},
     {"bg_phonetic",	"Български - Phonetic"},
     {"faen",		"Persian, English"},
+    {"mk",		"Македонски"},
     {NULL,		NULL}
 };
 
@@ -128,6 +130,15 @@ static GList *get_layouts(gchar *path, gchar *model, GList *list)
 				continue;
 			}
 
+			/* WORKAROUND: ignore cz_qwerty nokiarx51 layout,
+			   because it's broken in PR1.1 and PR1.1.1 */
+			if (!strcmp(model, "nokiarx51")) {
+				if (!strcmp(layout, "cz_qwerty")) {
+					layout = NULL;
+					continue;
+				}
+			}
+
 			name = resolve_layout_name(layout);
 			if (name)
 			{
